@@ -89,10 +89,10 @@ def test_diff__format_default():
 Name            Stmts    Miss    Cover    Missing
 --------------  -------  ------  -------  ----------
 dummy/__init__  -        -       -
-dummy/dummy     -        -2      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2    +2       +1      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3    +2       +2      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL           -1       -4      +31.06%
+dummy/dummy     -        \x1b[32m-2\x1b[39m      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
+dummy/dummy2    +2       \x1b[31m+1\x1b[39m      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
+dummy/dummy3    +2       \x1b[31m+2\x1b[39m      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
+TOTAL           -1       \x1b[32m-4\x1b[39m      +31.06%
 """
     else:
         assert result.output == """\
@@ -122,10 +122,10 @@ def test_diff__format_text():
 Name            Stmts    Miss    Cover    Missing
 --------------  -------  ------  -------  ----------
 dummy/__init__  -        -       -
-dummy/dummy     -        -2      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
-dummy/dummy2    +2       +1      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
-dummy/dummy3    +2       +2      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
-TOTAL           -1       -4      +31.06%
+dummy/dummy     -        \x1b[32m-2\x1b[39m      +40.00%  \x1b[32m-5\x1b[39m, \x1b[32m-6\x1b[39m
+dummy/dummy2    +2       \x1b[31m+1\x1b[39m      -25.00%  \x1b[32m-2\x1b[39m, \x1b[32m-4\x1b[39m, \x1b[31m+5\x1b[39m
+dummy/dummy3    +2       \x1b[31m+2\x1b[39m      -        \x1b[31m+1\x1b[39m, \x1b[31m+2\x1b[39m
+TOTAL           -1       \x1b[32m-4\x1b[39m      +31.06%
 """
         else:
             assert result.output == """\
@@ -209,13 +209,13 @@ def test_diff__format_html__with_source():
     assert result.output.endswith('</html>\n')
 
 
-def test_diff__format_html__missed():
+def test_diff__format_html__source():
     from pycobertura.cli import diff
 
     runner = CliRunner()
     result = runner.invoke(diff, [
         '--format', 'html',
-        '--missed',
+        '--source',
         'tests/dummy.source1/coverage.xml',
         'tests/dummy.source2/coverage.xml',
     ], catch_exceptions=False)
@@ -224,7 +224,7 @@ def test_diff__format_html__missed():
     assert result.output.endswith('</html>\n')
 
 
-def test_diff__format_html__missed_is_default():
+def test_diff__format_html__source_is_default():
     from pycobertura.cli import diff
 
     runner = CliRunner()
@@ -238,13 +238,13 @@ def test_diff__format_html__missed_is_default():
     assert result.output.endswith('</html>\n')
 
 
-def test_diff__format_html__no_missed():
+def test_diff__format_html__no_source():
     from pycobertura.cli import diff
 
     runner = CliRunner()
     result = runner.invoke(diff, [
         '--format', 'html',
-        '--no-missed',
+        '--no-source',
         'tests/dummy.source1/coverage.xml',
         'tests/dummy.source2/coverage.xml',
     ], catch_exceptions=False)
@@ -264,23 +264,25 @@ def test_diff__same_coverage_has_exit_status_of_zero():
     assert result.exit_code == 0
 
 
-def test_diff__better_coverage_has_exit_status_of_zero():
+def test_diff__all_changes_covered_has_exit_status_of_zero():
     from pycobertura.cli import diff
 
     runner = CliRunner()
     result = runner.invoke(diff, [
-        'tests/dummy.source1/coverage.xml',
-        'tests/dummy.source2/coverage.xml',
+        'tests/dummy.original.xml',
+        'tests/dummy.original-full-cov.xml',  # has no uncovered lines
+        '--no-source',
     ], catch_exceptions=False)
     assert result.exit_code == 0
 
 
-def test_diff__worse_coverage_has_exit_status_of_one():
+def test_diff__not_all_changes_covered_has_exit_status_of_one():
     from pycobertura.cli import diff
 
     runner = CliRunner()
     result = runner.invoke(diff, [
-        'tests/dummy.source2/coverage.xml',
-        'tests/dummy.source1/coverage.xml',
+        'tests/dummy.with-dummy2-no-cov.xml',
+        'tests/dummy.with-dummy2-better-and-worse.xml',  # has covered AND uncovered lines
+        '--no-source',
     ], catch_exceptions=False)
     assert result.exit_code == 1
